/* StringTurtleApplet.java -- StringTurtle Applet.
**
** Copyright (C) 1997-2002 Eric Laroche.  All rights reserved.
**
** @author Eric Laroche <laroche@lrdev.com>
** @version @(#)$Id: StringTurtleApplet.java,v 1.1 2002/12/26 17:10:11 laroche Exp $
**
** This program is free software;
** you can redistribute it and/or modify it.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
**
*/

package com.lrdev.turtle;

// note: no wildcard imports

// Use the AWT based graphics turtle.
import com.lrdev.turtle.StringTurtle;

import java.applet.Applet;
import java.awt.Color;
import java.awt.Event;
import java.awt.Graphics;
import java.awt.Rectangle;
import java.io.PrintStream;

/** StringTurtleApplet: StringTurtle Applet.
*
* @author Eric Laroche <laroche@lrdev.com>
* @version @(#)$Id: StringTurtleApplet.java,v 1.1 2002/12/26 17:10:11 laroche Exp $
* @url http://www.lrdev.com/lr/java/javaturtle.html
*
* @see com.lrdev.turtle.StringTurtle
* @see com.lrdev.turtle.Turtle
*/
public class StringTurtleApplet
	extends Applet
{
	/** Version.
	*/
	private final static String m_version =
		"Version: @(#)$Id: StringTurtleApplet.java,v 1.1 2002/12/26 17:10:11 laroche Exp $";

	/** Author.
	*/
	private final static String m_author =
		"Author: Eric Laroche <laroche@lrdev.com>";

	/** Copyright.
	*/
	private final static String m_copyright =
		"Copyright (C) 1997-2002 Eric Laroche.  All rights reserved.";

	// note: have this disclaimer as one string literal,
	// i.e. no '+' string concatenation (C string concatenation not supported by Java).
	/** Disclaimer.
	*/
	private final static String m_disclaimer =
		"This program is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.";

	/** Application program name.
	*/
	private final static String m_programName =
		"StringTurtleApplet";

	/** Applet usage.
	*/
	private final static String[][] m_usage = {
		{"execute", "String", "Turtle commands"},
	};

	/** Turtle commands string.
	*/
	private String m_execute = null;

	/** Entry point for a standalone application program.
	*/
	public static void main(String[] args)
	{
		// usage
		printUsage(System.err);
	}

	/** Print usage info.
	*/
	protected static void printUsage(PrintStream out)
	{
		out.println("Sorry, you must run " + m_programName + " as an applet.");
		out.println("");
		printInfo(out);
	}

	/** Print version info, disclaimer, etc.
	*/
	protected static void printInfo(PrintStream out)
	{
		out.println(m_version);
		out.println(m_author);
		out.println(m_copyright);
		out.println("");
		out.println(m_disclaimer);
	}

	/** Called by the browser.
	* Returns info on this applet.
	*
	* Overwrites Applet.getAppletInfo.
	*/
	public String getAppletInfo()
	{
		return m_version + "\n" + m_author;
	}

	/** Called by the browser.
	* Returns info on the parameters of this applet.
	*
	* Overwrites Applet.getParameterInfo.
	*/
	public String[][] getParameterInfo()
	{
		return m_usage;
	}

	/** Constructor.
	*/
	public StringTurtleApplet()
	{
		// NOTE: must postpone getParameter() calls to init()
	}

	/** Called after the constructor and before start().
	* Sets the background color and reads in the applet parameters.
	*
	* Overwrites Applet.init.
	*/
	public void init()
	{
		m_execute = getParameter("execute");

		// white background, black foreground
		setBackground(Color.white);
		setForeground(Color.black);
	}

	/** Called by the browser.
	*
	* Overwrites Applet.start.
	*/
	public void start()
	{
	}

	/* Called by the browser.
	*
	* Overwrites Applet.stop.
	*/
	public void stop()
	{
	}

	/** Called by the browser.
	*
	* Overwrites Applet.destroy.
	*/
	public void destroy()
	{
	}

	/** Paint the component.
	*
	* Overwrites Component.paint.
	*/
	public void paint(Graphics graphics)
	{
		// get the bounding rectangle.
		Rectangle r = bounds();

		if (r == null) {
			return;
		}

		if (m_execute == null) {
			return;
		}

		StringTurtle turtle = new StringTurtle(graphics, r);
		turtle.execute(m_execute);
   	}
}

